JsClass<T extends Object> class final

Explicit descriptor for a Dart class exposed as a JavaScript constructor.

The constructor returns a JS instance synchronously, while the Dart instance is created through the Promise callback bridge. Instance getters and methods wait for that constructor Promise before touching the Dart instance.

Constructors

JsClass({required JsClassConstructor<T> create, required JsMembers<T> members})
Creates a class injection descriptor.
const

Properties

create JsClassConstructor<T>
Dart constructor invoked with JavaScript arguments.
final
hashCode int
The hash code for this object.
no setterinherited
members JsMembers<T>
Instance members exposed on constructed JavaScript objects.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited