JsClassHandle class final

Runtime-owned handle to a JavaScript constructor binding.

Properties

disposed bool
Whether this Dart handle has been explicitly disposed.
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
Global constructor name used in the owning runtime.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
Releases the JS constructor, hidden callbacks, and Dart instance table.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited