JsPluginRegistry class final

Registry for calling plugin exports through pluginId.method names.

Constructors

JsPluginRegistry(JsEngine engine)
创建通过 engine 执行已注册插件的 Registry。

Properties

engine JsEngine
Registry 用于验证和调用插件的 Engine。
final
hashCode int
The hash code for this object.
no setterinherited
plugins Iterable<JsPlugin>
当前已注册插件的只读视图。
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(String pluginId, String method, List<Object?> args, {Duration? timeout}) Future<Object?>
调用 pluginId 插件声明的 method 导出。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(JsPlugin plugin) JsPluginRegistry
注册 plugin 并返回当前 Registry 以支持链式配置。
toString() String
A string representation of this object.
inherited
unregister(String pluginId) JsPluginRegistry
注销 pluginId 对应的插件并返回当前 Registry。
validateAll({Duration? timeout}) Future<void>
依次验证所有已注册插件。

Operators

operator ==(Object other) bool
The equality operator.
inherited