JsValueConversionException class final

eval() 遇到无法直接映射为 Dart 值的 JS 值。

Implemented types
Available extensions

Constructors

JsValueConversionException([String message = 'QuickJS value cannot be converted to a Dart value'])
Creates a value-conversion failure with an optional diagnostic message.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
kind JsErrorKind

Available on JsException, provided by the JsExceptionKind extension

Framework category used for recovery and reporting decisions.
no setter
message String
Stable human-readable error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited