StorageFeatures class base

将一个已经绑定命名空间的 KV Store 暴露为 ES module。

Inheritance

Constructors

StorageFeatures({JsKvStore? store, String? namespace, String moduleSpecifier = 'lemon_js/storage', String? name})
创建导出 KV Store ES module 的默认能力集合。
factory
StorageFeatures.custom({required JsKvStore store, required String? namespace, required String moduleSpecifier, required String? name})
供需要自定义模块名的组合层使用。

Properties

browserGlobals JsGlobals
Browser-like global aliases installed before scripts.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
methods List<JsHostMethod>
注入 JavaScript 的 Dart/Flutter 宿主方法。
finalinherited
modules List<JsModule>
ES module and CommonJS definitions included in this features.
finalinherited
name String
Stable name used for conflict detection and debug inspection.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scripts List<JsScript>
Ordered scripts that complete the runtime global environment.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited