activeContextCount property
int
get
activeContextCount
Number of live child contexts, primarily useful for capacity diagnostics.
Implementation
int get activeContextCount => _contexts.length;
Number of live child contexts, primarily useful for capacity diagnostics.
int get activeContextCount => _contexts.length;