JsWeb class

Flutter Web 插件注册入口。

这里只做 best-effort 预加载;真正初始化会由 JsEngine.create() 等待完成。

Constructors

JsWeb()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void
注册 Flutter Web 插件并预加载 Lemon JS Web Host。