JsQueueFullException class final
runtime 的串行调用队列已经达到宿主配置的上限。
- Implemented types
- Available extensions
Constructors
- JsQueueFullException([String message = 'QuickJS evaluation queue is full'])
-
Creates an error for a request rejected by the waiting-task limit.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → JsErrorKind
-
Available on JsException, provided by the JsExceptionKind extension
Framework category used for recovery and reporting decisions.no setter - message → String
-
Stable human-readable error message.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited