JsRuntimeState enum
JsEngine 实例当前可观察的生命周期状态。
Values
- ready → const JsRuntimeState
-
Runtime 可接受并执行新的请求。
- running → const JsRuntimeState
-
Runtime 正在执行一个 eval 请求。
- restarting → const JsRuntimeState
-
Runtime 正在停止当前请求并恢复可用状态。
- closed → const JsRuntimeState
-
Runtime 已被 dispose,不能再使用。
- failed → const JsRuntimeState
-
Runtime worker 已崩溃或进入不可恢复失败状态。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
JsRuntimeState> - A constant List of the values in this enum, in order of their declaration.