JsValueConversionException constructor
const
JsValueConversionException([
- String message = 'QuickJS value cannot be converted to a Dart value'
Creates a value-conversion failure with an optional diagnostic message.
Implementation
const JsValueConversionException([
this.message = 'QuickJS value cannot be converted to a Dart value',
]);