NodeFeatures class final
提供最小 Node-like 模块环境,不包含 fs、网络或完整 npm resolver。
- Inheritance
-
- Object
- JsFeatures
- NodeFeatures
Constructors
Properties
- browserGlobals → JsGlobals
-
Browser-like global aliases installed before scripts.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
methods
→ List<
JsHostMethod> -
注入 JavaScript 的 Dart/Flutter 宿主方法。
finalinherited
-
modules
→ List<
JsModule> -
ES module and CommonJS definitions included in this features.
finalinherited
- name → String
-
Stable name used for conflict detection and debug inspection.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scripts
→ List<
JsScript> -
Ordered scripts that complete the runtime global environment.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited